@@ -34,7 +34,8 @@ class ExpaiModelFairness:
         json = {
             "sample_id": sample_id,
             "subset_indexes": subset_indexes,
-            "protected_columns": protected_columns
+            "protected_columns": ",".join(protected_columns) if protected_columns else None,
+            "get_html": True
         }
 
         response = self.sess.request("POST",
@@ -43,8 +44,7 @@ class ExpaiModelFairness:
 
         if response.ok:
             html = response.json()['html']
-            display(HTML(html))
-            return html
+            display(HTML(html), metadata=dict(isolated=True))
 
         else:
             return generate_response(response, ['html'])
