@@ -23,6 +23,7 @@ class ExpaiProject:
     #########################
     ###      MODELS       ###
     #########################
+
     def model_list(self, search_by: str = None, exact_search: str = None):
         """
         List all models within the project
@@ -361,7 +362,16 @@ class ExpaiProject:
         else:
             return generate_response(response)
 
-    def get_sample(self, sample_name: str = None, sample_id: str = None, drop_target: bool = True):
+    def get_sample(self, sample_name: str = None, sample_id: str = None, subset_filters: dict = None, drop_target: bool = None, drop_columns: bool = None):
+        """
+        Returns a pandas DataFrame from your stored sample.
+        :param sample_name: Name of the sample (use this parameter OR sample_id)
+        :param sample_id: Unique ID for the sample
+        :param subset_filters: Dictionary with filters (see documentation)
+        :param drop_target: True if you want to drop the target column
+        :param drop_columns: True if you want to drop your drop columns
+        :return: dataframe
+        """
         assert sample_id is not None or sample_name is not None, "You must indicate the sample_name or sample_id"
 
         if sample_id is None:
@@ -372,19 +382,19 @@ class ExpaiProject:
                     "We could not find any sample matching that name. Please, try again or use sample_id as parameter")
                 return False
 
-        response = self.sess.request("GET", self.server_name + "/api/projects/{}/sample/{}/get".format(self.project_id, sample_id), headers=self.headers)
+        data = {"subset_filters": subset_filters,
+                "drop_target_cols": drop_target,
+                "drop_cols": drop_columns}
+
+        response = self.sess.request("POST", self.server_name + "/api/projects/{}/sample/{}/get".format(self.project_id, sample_id),
+                                     headers=self.headers, json=data)
 
         if response.ok:
-            encoding = response.headers['encoding']
-            separator = response.headers['separator']
-            df = pd.read_csv(io.StringIO(response.content.decode(encoding)), index_col=0, sep=separator)
-            if drop_target is True:
-                try:
-                    drop_col = ast.literal_eval(response.headers['drop_cols'])
-                    df = df.drop(columns=drop_col)
-                except:
-                    logging.error("There was en error dropping the target column. Please, try setting drop_target to False")
-            return df
+            if 'data' in response.json():
+                df = pd.read_json(response.json().get('data'), orient='records')
+                return df
+            else:
+                raise Exception("There was en error generating the DataFrame. No data was returned from API. Please, try again.")
         else:
             return generate_response(response)
 
